==> nextcloud-app-contacts-3.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/sv.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "Details" : "Detaljer",
    "A contacts app for Nextcloud" : "En kontakt-app för Nextcloud",
    "Add new property" : "Lägg till nytt fält",
    "Choose property type" : "Välj typ",
    "Upload a new picture" : "Ladda upp en ny bild",
    "Image is too big (max 1MB)." : "Bilden är för stor (max 1MB)",
    "No contact selected" : "Ingen kontakt vald",
    "Select a contact on the list to begin" : "Välj en kontakt i listan för att börja",
    "Loading" : "Laddar",
    "Name" : "Namn",
    "Company" : "Företag",
    "Title" : "Titel",
    "This contact is not yet synced. Edit it to save it to the server." : "Den här kontakten är ännu inte synkroniserad. Redigera den för att spara på servern.",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Den här kontakten är skrivskyddad. Du har inte behörighet att redigera den här kontakten.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du försökte redigera har ändrats. Uppdatera kontakten manuellt. Eventuella ytterligare ändringar kommer att kasseras.",
    "Download" : "Ladda ned",
    "Delete" : "Radera",
    "Addressbook" : "Adressbok",
    "Groups" : "Grupper",
    "New contact" : "Ny kontakt",
    "The contact doesn't exists anymore on the server." : "Kontakten finns inte längre på servern.",
    "Importing {total} contacts into" : "Importerar {total} kontakter till",
    "Open your browser console for more details" : "Öppna din webbläsarkonsol för mer information",
    "failed" : "misslyckades",
    "Select type" : "Välj typ",
    "Select Date" : "Välj datum",
    "Add contact in group" : "Lägg till kontakt i grupp",
    "No results" : "Inga resultat",
    "Select option" : "Välj alternativ",
    "Copy link" : "Kopiera länk",
    "Copied" : "Kopierad",
    "Can not copy" : "Kunde inte kopiera",
    "Rename" : "Byt namn",
    "Enabled" : "Aktiverad",
    "Disabled" : "Inaktiverad",
    "Enabled toggle of addressbook was not successful." : "Aktiverad växling av adressboken lyckades inte.",
    "This will delete the addressbook and every contacts within it" : "Detta tar bort adressboken och alla kontakter i den",
    "Delete {addressbook} ?" : "Radera {addressbook} ?",
    "Deletion of addressbook was not successful." : "Radering av adressboken lyckades inte.",
    "Renaming of addressbook was not successful." : "Namnbyte av adressboken lyckades inte.",
    "Addressbook copied to clipboard" : "Adressbok kopierad till urklipp",
    "Addressbook was not copied to clipboard." : "Adressbok kopierades inte till urklipp",
    "Share with users or groups" : "Dela med användare eller grupper",
    "No users or groups" : "Inga användare eller grupper",
    "can edit" : "kan redigera",
    "Unable to delete the share." : "Kan inte ta bort delningen.",
    "Unable to change permissions." : "Kan inte ändra behörigheter.",
    "Importing into" : "Importerar till",
    "Import into" : "Importera till",
    "Importing is disabled because there are no address books available" : "Importera är inaktiverad eftersom det inte finns några adressböcker tillgängliga",
    "Address book name" : "Adressbokens namn",
    "An error occurred, unable to create the addressbook." : "Ett fel uppstod, kunde inte skapa adressboken.",
    "First name" : "Förnamn",
    "Last name" : "Efternamn",
    "Display name" : "Visningsnamn",
    "Sort by {sorting}" : "Sortera efter {sorting}",
    "All contacts" : "Alla kontakter",
    "Unable to create the contact." : "Kunde inte skapa kontakten.",
    "Contact not found" : "Kontakt ej hittad",
    "Nickname" : "Smeknamn",
    "Detailed name" : "Detaljerat namn",
    "Additional names" : "Mellannamn",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Notes" : "Anteckningar",
    "Website" : "Webbplats",
    "Federated Cloud ID" : "Federerat Moln-ID",
    "Home" : "Hem",
    "Work" : "Arbete",
    "Other" : "Övrigt",
    "Address" : "Adress",
    "Post office box" : "Postbox",
    "Extended address" : "Utökad adress",
    "City" : "Stad",
    "State or province" : "Län eller Kommun",
    "Postal code" : "Postnummer",
    "Country" : "Land",
    "Birthday" : "Födelsedag",
    "Anniversary" : "Födelsedag",
    "Date of death" : "Dödsdag",
    "Email" : "E-post",
    "Instant messaging" : "Snabbmeddelanden",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Mobil arbete",
    "Home mobile" : "Mobil hem",
    "Fax" : "Fax",
    "Fax home" : "Fax hem",
    "Fax work" : "Fax arbete",
    "Pager" : "Personsökare",
    "Voice" : "Röst",
    "Car" : "Bil",
    "Work pager" : "Personsökare Arbete",
    "Social network" : "Socialt nätverk",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "Profilens URL. e.x. https://www.facebook.com/Nextclouders/ ",
    "Relationship" : "Relation",
    "Specify a relationship between you and the entity represented by this vCard." : "Ange relationen mellan dig och den som representeras av detta vCard.",
    "Spouse" : "Make/Maka",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Förälder",
    "Brother" : "Bror",
    "Sister" : "Syster",
    "Relative" : "Släkting",
    "Friend" : "Vän",
    "Colleague" : "Kollega",
    "Manager" : "Chef",
    "Assistant" : "Assistent",
    "Related" : "Relaterad",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Ange relationen mellan en annan enhet och den enhet som representeras av detta vCard.",
    "Contact" : "Kontakt",
    "Agent" : "Agent",
    "Emergency" : "Nödsituation",
    "Co-worker" : "Kollega",
    "Gender" : "Kön",
    "Female" : "Kvinna",
    "Male" : "Man",
    "An error occurred" : "Ett fel uppstod"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-contacts-3.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/sv.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakter",
    "All contacts" : "Alla kontakter",
    "Details" : "Detaljer",
    "A contacts app for Nextcloud" : "En kontakt-app för Nextcloud",
    "Add new property" : "Lägg till nytt fält",
    "Choose property type" : "Välj typ",
    "Upload a new picture" : "Ladda upp en ny bild",
    "Image is too big (max 1MB)." : "Bilden är för stor (max 1MB)",
    "No contact selected" : "Ingen kontakt vald",
    "Select a contact on the list to begin" : "Välj en kontakt i listan för att börja",
    "Loading" : "Laddar",
    "Name" : "Namn",
    "Company" : "Företag",
    "Title" : "Titel",
    "This contact is not yet synced. Edit it to save it to the server." : "Den här kontakten är ännu inte synkroniserad. Redigera den för att spara på servern.",
    "This contact is in read-only mode. You do not have permission to edit this contact." : "Den här kontakten är skrivskyddad. Du har inte behörighet att redigera den här kontakten.",
    "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "Kontakten du försökte redigera har ändrats. Uppdatera kontakten manuellt. Eventuella ytterligare ändringar kommer att kasseras.",
    "Download" : "Ladda ned",
    "Delete" : "Radera",
    "Addressbook" : "Adressbok",
    "Groups" : "Grupper",
    "New contact" : "Ny kontakt",
    "The contact doesn't exists anymore on the server." : "Kontakten finns inte längre på servern.",
    "Importing {total} contacts into" : "Importerar {total} kontakter till",
    "Open your browser console for more details" : "Öppna din webbläsarkonsol för mer information",
    "failed" : "misslyckades",
    "Select type" : "Välj typ",
    "Select Date" : "Välj datum",
    "Add contact in group" : "Lägg till kontakt i grupp",
    "No results" : "Inga resultat",
    "Select option" : "Välj alternativ",
    "Copy link" : "Kopiera länk",
    "Copied" : "Kopierad",
    "Can not copy" : "Kunde inte kopiera",
    "Rename" : "Byt namn",
    "Enabled" : "Aktiverad",
    "Disabled" : "Inaktiverad",
    "Enabled toggle of addressbook was not successful." : "Aktiverad växling av adressboken lyckades inte.",
    "This will delete the addressbook and every contacts within it" : "Detta tar bort adressboken och alla kontakter i den",
    "Delete {addressbook} ?" : "Radera {addressbook} ?",
    "Deletion of addressbook was not successful." : "Radering av adressboken lyckades inte.",
    "Renaming of addressbook was not successful." : "Namnbyte av adressboken lyckades inte.",
    "Addressbook copied to clipboard" : "Adressbok kopierad till urklipp",
    "Addressbook was not copied to clipboard." : "Adressbok kopierades inte till urklipp",
    "Share with users or groups" : "Dela med användare eller grupper",
    "No users or groups" : "Inga användare eller grupper",
    "can edit" : "kan redigera",
    "Unable to delete the share." : "Kan inte ta bort delningen.",
    "Unable to change permissions." : "Kan inte ändra behörigheter.",
    "Importing into" : "Importerar till",
    "Import into" : "Importera till",
    "Importing is disabled because there are no address books available" : "Importering är inaktiverat eftersom att det inte finns några adressböcker tillgängliga",
    "Address book name" : "Adressbokens namn",
    "An error occurred, unable to create the addressbook." : "Ett fel uppstod, kunde inte skapa adressboken.",
    "First name" : "Förnamn",
    "Last name" : "Efternamn",
    "Display name" : "Visningsnamn",
    "Sort by {sorting}" : "Sortera efter {sorting}",
    "Unable to create the contact." : "Kunde inte skapa kontakten.",
    "Contact not found" : "Kontakt ej hittad",
    "Nickname" : "Smeknamn",
    "Detailed name" : "Detaljerat namn",
    "Additional names" : "Mellannamn",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "Notes" : "Anteckningar",
    "Website" : "Webbplats",
    "Federated Cloud ID" : "Federerat Moln-ID",
    "Home" : "Hem",
    "Work" : "Arbete",
    "Other" : "Övrigt",
    "Address" : "Adress",
    "Post office box" : "Postbox",
    "Extended address" : "Utökad adress",
    "City" : "Stad",
    "State or province" : "Län eller Kommun",
    "Postal code" : "Postnummer",
    "Country" : "Land",
    "Birthday" : "Födelsedag",
    "Anniversary" : "Födelsedag",
    "Date of death" : "Dödsdag",
    "Email" : "E-post",
    "Instant messaging" : "Snabbmeddelanden",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Work mobile" : "Mobil arbete",
    "Home mobile" : "Mobil hem",
    "Fax" : "Fax",
    "Fax home" : "Fax hem",
    "Fax work" : "Fax arbete",
    "Pager" : "Personsökare",
    "Voice" : "Röst",
    "Car" : "Bil",
    "Work pager" : "Personsökare Arbete",
    "Social network" : "Socialt nätverk",
    "The url of the profile. e.g. https://www.facebook.com/Nextclouders/ " : "Profilens URL. e.x. https://www.facebook.com/Nextclouders/ ",
    "Relationship" : "Relation",
    "Specify a relationship between you and the entity represented by this vCard." : "Ange relationen mellan dig och den som representeras av detta vCard.",
    "Spouse" : "Make/Maka",
    "Child" : "Barn",
    "Mother" : "Mor",
    "Father" : "Far",
    "Parent" : "Förälder",
    "Brother" : "Bror",
    "Sister" : "Syster",
    "Relative" : "Släkting",
    "Friend" : "Vän",
    "Colleague" : "Kollega",
    "Manager" : "Chef",
    "Assistant" : "Assistent",
    "Related" : "Relaterad",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Ange relationen mellan en annan enhet och den enhet som representeras av detta vCard.",
    "Contact" : "Kontakt",
    "Agent" : "Agent",
    "Emergency" : "Nödsituation",
    "Co-worker" : "Kollega",
    "Gender" : "Kön",
    "Female" : "Kvinna",
    "Male" : "Man",
    "An error occurred" : "Ett fel uppstod"
},
"nplurals=2; plural=(n != 1);");
